pg_jts
======

Create JSON-table-schemas from a live PostgreSQL database

Python3 alpha code

(JSON table schema is an extensible standard for describing tabular data:
http://dataprotocols.org/json-table-schema
)

Documentation: https://pg_jts.readthedocs.org/

If you provide patches, please also consider patching https://github.com/iburadempa/jts_erd/ accordingly.
